//+------------------------------------------------------------------------+
//|                                                                        |
//| Double Positions Scalper V4.mq4                                        |
//| Copyright  2007 by Marc Tardif                                        |
//| mdt38@rogers.com                                                       |
//| http://www.inlinetrader.com/?RefID=Freedom38                           |
//| Last modified by Marc Tardif on December 26, 2007                      |
//|                                                                        |
//| For running on Interbank FX mini account.                              |
//|                                                                        |
//| Results: 94% profitable trades 2005-2007 ???                           |
//| 1. Always have two positions open.                                     |
//|    - 1st position: TP +400, SL -200.                                   |
//|    - 2nd position: TP +400, SL -400.                                   |
//|                                                                        |
//+------------------------------------------------------------------------+
#property copyright "Copyright  2007 Marc Tardif"
#property link      "http://www.inlinetrader.com/?RefID=Freedom38"

extern int TakeProfitPips = 150;           // Take Profit target expressed in pips.
extern int StopLossPips = 150;             // Stop Loss target expressed in pips.
extern double LotRatio = 1.00;             // Ratio of lot size to lot value.
extern int Slippage = 5;                   // Maximum slippage (in pips) when opening positions.
extern int SystemNumber = 20071207;        // Number used to identify positions generated by this system.
extern string SystemName = "Double Positions"; // Comment used to identify positions generated by this system.

//---- Variables related to Money Management.
double LotValue = 0;                       // Lot value (contract size) of current symbol.
double TickValue = 0;                      // Tick value of current symbol.
double Delta = 0;                          // Fixed ratio money management delta.
double TradeLots = 0;                      // Number of lots to trade when opening new position.

//---- Variables related to position management.
int Counter = 0;                           // Counter for "for" loops.
int OpenOrders = 0;                        // Number of open positions.
int OpenLongOrders = 0;                    // Number of open long positions.
int OpenShortOrders = 0;                   // Number of open short positions.
double Spread = 0;                         // Bid/Ask spread.
double SL = 0;                             // Stop Loss.
double TP = 0;                             // Take Profit.
double LongProfitPips = 0;                     // Profit of open long positions (in pips).
double ShortProfitPips = 0;                     // Profit of open short positions (in pips).

//---- Variables related to trend.

//---- Variables related to momentum.
double Weekly_Stoch_Main_0 = 0;
double Weekly_Stoch_Main_1 = 0;
double Weekly_Stoch_Main_2 = 0;
double Weekly_Stoch_Signal_0 = 0;
double Weekly_Stoch_Signal_1 = 0;
double Weekly_Stoch_Signal_2 = 0;
int    Weekly_Stoch_Cross = 0;
int    Weekly_Stoch_Cross_Prev = 0;
int    Weekly_Stoch_Momentum = 0;
double Hourly_Stoch_Main_0 = 0;
double Hourly_Stoch_Main_1 = 0;
double Hourly_Stoch_Signal_0 = 0;
double Hourly_Stoch_Signal_1 = 0;
int    Hourly_Stoch_Cross = 0;
int    Hourly_Stoch_Cross_Prev = 0;


//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
  {
   //---- Determine Lot Value (Contract Size) for current symbol.
   LotValue = MarketInfo(Symbol(), MODE_LOTSIZE);
   
   //---- Determine Tick value for current symbol.
   //---- Tick value will be exact for symbols where the second currency matches
   //---- the account currency (for example, account in USD and symbol is GBPUSD).
   //---- Tick value will be approximate for symbols where the second currency does
   //---- not match the account currency (for example, account in USD and symbol is USDCAD).
   TickValue = MarketInfo(Symbol(), MODE_TICKVALUE);
   
   //---- Record the fixed ratio money management delta.
   //---- The delta represents the increase in equity required to increase the
   //---- size of trade lots by 1 whole lot.
   Delta = NormalizeDouble(LotValue/LotRatio, 2);

   return(0);
  }

  
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
  {
   return(0);
  }


//+---------------------------------------------------------------------+
//| Fixed ratio money management to determine lot size.                 |
//| Each 1% change in account equity causes 1% change in lot size.      |
//+---------------------------------------------------------------------+
double LotSize (double CurrentEquity)
  {
   double NewLots = 0;
   NewLots = NormalizeDouble(CurrentEquity/LotValue*LotRatio, 2);   
   return(NewLots);
  }


//+------------------------------------------------------------------+
//| Expert start function                                            |
//+------------------------------------------------------------------+
int start()
  {
   //---- Record the Bid/Ask spread.
   Spread = (Ask - Bid);

   //---- Determine the long-term momentum on the weekly chart.
   Weekly_Stoch_Main_0 = iStochastic (NULL, PERIOD_W1, 13, 3, 3, MODE_SMMA, 1, MODE_MAIN, 0);
   Weekly_Stoch_Main_1 = iStochastic (NULL, PERIOD_W1, 13, 3, 3, MODE_SMMA, 1, MODE_MAIN, 1);
   Weekly_Stoch_Main_2 = iStochastic (NULL, PERIOD_W1, 13, 3, 3, MODE_SMMA, 1, MODE_MAIN, 2);
   Weekly_Stoch_Signal_0 = iStochastic (NULL, PERIOD_W1, 13, 3, 3, MODE_SMMA, 1, MODE_SIGNAL, 0);
   Weekly_Stoch_Signal_1 = iStochastic (NULL, PERIOD_W1, 13, 3, 3, MODE_SMMA, 1, MODE_SIGNAL, 1);
   Weekly_Stoch_Signal_2 = iStochastic (NULL, PERIOD_W1, 13, 3, 3, MODE_SMMA, 1, MODE_SIGNAL, 2);
   
   if (Weekly_Stoch_Main_1 > Weekly_Stoch_Signal_1 && Weekly_Stoch_Main_2 < Weekly_Stoch_Signal_2)
     Weekly_Stoch_Cross = 1;
   else if (Weekly_Stoch_Main_1 < Weekly_Stoch_Signal_1 && Weekly_Stoch_Main_2 > Weekly_Stoch_Signal_2)
     Weekly_Stoch_Cross = -1;
   else
     Weekly_Stoch_Cross = 0;  
     
   if (Weekly_Stoch_Main_1 > Weekly_Stoch_Signal_1 && Weekly_Stoch_Main_2 > Weekly_Stoch_Signal_2)
     Weekly_Stoch_Momentum = 1;
   else if (Weekly_Stoch_Main_1 < Weekly_Stoch_Signal_1 && Weekly_Stoch_Main_2 < Weekly_Stoch_Signal_2)
     Weekly_Stoch_Momentum = -1;
   else
     Weekly_Stoch_Momentum = 0;  
     
   //---- Determine the short-term momentum on the 4-hour chart.
   Hourly_Stoch_Main_0 = iStochastic (NULL, PERIOD_H4, 13, 3, 3, MODE_SMMA, 1, MODE_MAIN, 0);
   Hourly_Stoch_Main_1 = iStochastic (NULL, PERIOD_H4, 13, 3, 3, MODE_SMMA, 1, MODE_MAIN, 1);
   Hourly_Stoch_Signal_0 = iStochastic (NULL, PERIOD_H4, 13, 3, 3, MODE_SMMA, 1, MODE_SIGNAL, 0);
   Hourly_Stoch_Signal_1 = iStochastic (NULL, PERIOD_H4, 13, 3, 3, MODE_SMMA, 1, MODE_SIGNAL, 1);
   
   if (Hourly_Stoch_Main_0 > Hourly_Stoch_Signal_0 && Hourly_Stoch_Main_1 < Hourly_Stoch_Signal_1)
     Hourly_Stoch_Cross = 1;
   else if (Hourly_Stoch_Main_0 < Hourly_Stoch_Signal_0 && Hourly_Stoch_Main_1 > Hourly_Stoch_Signal_1)
     Hourly_Stoch_Cross = -1;
   else
     Hourly_Stoch_Cross = 0;  
   
   

   //---- Reset variables related to position management.  
   OpenOrders = 0;
   
   OpenLongOrders = 0;
   LongProfitPips = 0;
   
   OpenShortOrders = 0;
   ShortProfitPips = 0;
   
   //---- Count number of open positions generated by this expert advisor.
   for(Counter = 0; Counter < OrdersTotal(); Counter++)   
     {
       OrderSelect(Counter, SELECT_BY_POS, MODE_TRADES);

       if (OrderMagicNumber() == SystemNumber)
         {
	  	    OpenOrders++;
	  	    
	  	    if (OrderType() == OP_BUY)
	  	      {
             OpenLongOrders++;
             LongProfitPips = ((OrderClosePrice() - OrderOpenPrice()) / Point) + LongProfitPips;
            }

	  	    if (OrderType() == OP_SELL)
	  	     {
            OpenShortOrders++;
            ShortProfitPips = ((OrderOpenPrice() - OrderClosePrice()) / Point) + ShortProfitPips;
           }
         }       
     }


   //---- Close open positions if signals change.
   for(Counter = 0; Counter < OrdersTotal(); Counter++)   
     {
       OrderSelect(Counter, SELECT_BY_POS, MODE_TRADES);

	  	    if (OrderType() == OP_BUY)
            {
             if (LongProfitPips >= 50)
               OrderClose (OrderTicket(), OrderLots(), OrderClosePrice(), Slippage, Blue);
            }

	  	    if (OrderType() == OP_SELL)
            {
             if (ShortProfitPips >= 50)
               OrderClose (OrderTicket(), OrderLots(), OrderClosePrice(), Slippage, Red);
            }
     }
   

   //---- Enter long positions if none currently exist. 
   if (
       (LongProfitPips <= 0 && Weekly_Stoch_Cross_Prev != 1 && Weekly_Stoch_Cross == 1 && Weekly_Stoch_Main_0 < 40) ||
       (LongProfitPips <= 0 && Hourly_Stoch_Cross_Prev != 1 && Hourly_Stoch_Cross == 1 && Hourly_Stoch_Main_0 < 40 
        && Weekly_Stoch_Momentum == 1)
       )
     {
      TradeLots = LotSize(AccountEquity());
      SL = Ask - (StopLossPips*Point);
      TP = Ask + (TakeProfitPips*Point);
      //OrderSend (Symbol(), OP_BUY, TradeLots, Ask, Slippage, 0, TP, SystemName, SystemNumber, 0, Blue);
      //OrderSend (Symbol(), OP_BUY, TradeLots, Ask, Slippage, SL, TP, SystemName, SystemNumber, 0, Blue);

      SL = Ask - (TakeProfitPips*Point);
      OrderSend (Symbol(), OP_BUY, TradeLots, Ask, Slippage, 0, 0, SystemName, SystemNumber, 0, Blue);
      //OrderSend (Symbol(), OP_BUY, TradeLots, Ask, Slippage, SL, TP, SystemName, SystemNumber, 0, Blue);

      Hourly_Stoch_Cross_Prev = Hourly_Stoch_Cross;
      Weekly_Stoch_Cross_Prev = Weekly_Stoch_Cross;
      OpenOrders++;
      OpenLongOrders++;
     }


   //---- Enter short positions if none currently exist. 
   if (
       (ShortProfitPips <= 0 && Weekly_Stoch_Cross_Prev != -1 && Weekly_Stoch_Cross == -1 && Weekly_Stoch_Main_0 > 60) ||
       (ShortProfitPips <= 0 && Hourly_Stoch_Cross_Prev != -1 && Hourly_Stoch_Cross == -1 && Hourly_Stoch_Main_0 > 60
        && Weekly_Stoch_Momentum == -1)
      )
       
     {
      TradeLots = LotSize(AccountEquity());
      SL = Bid + (StopLossPips*Point);
      TP = Bid - (TakeProfitPips*Point);
      //OrderSend (Symbol(), OP_SELL, TradeLots, Ask, Slippage, 0, TP, SystemName, SystemNumber, 0, Red);
      //OrderSend (Symbol(), OP_SELL, TradeLots, Ask, Slippage, SL, TP, SystemName, SystemNumber, 0, Red);

      SL = Bid + (TakeProfitPips*Point);
      OrderSend (Symbol(), OP_SELL, TradeLots, Ask, Slippage, 0, 0, SystemName, SystemNumber, 0, Red);
      //OrderSend (Symbol(), OP_SELL, TradeLots, Ask, Slippage, SL, TP, SystemName, SystemNumber, 0, Red);

      Hourly_Stoch_Cross_Prev = Hourly_Stoch_Cross;
      Weekly_Stoch_Cross_Prev = Weekly_Stoch_Cross;
      OpenOrders++;
      OpenShortOrders++;
     }

   return(0);
  }
//+------------------------------------------------------------------+